#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 githash
version:              0.1.6.3
visibility:           public
id:                   githash-0.1.6.3-GUPPgRbB6OuEbmCcGv8KZB
key:                  githash-0.1.6.3-GUPPgRbB6OuEbmCcGv8KZB
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  1f99e461c8552b5e81a1544c40354361
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-9.6.6/site-local/githash-0.1.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/githash-0.1.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/githash-0.1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-githash
hs-libraries:         HSgithash-0.1.6.3-GUPPgRbB6OuEbmCcGv8KZB
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 process-1.6.19.0 template-haskell-2.20.0.0
    th-compat-0.1.7-Ha5PRJluq5sC7gmCQw3lIQ

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

